@@ -696,12 +696,12 @@ sub AAT_write_lookup
 
 =head1 AUTHOR
 
-Jonathan Kew L<Jonathan_Kew@sil.org>. 
+Jonathan Kew L<http://scripts.sil.org/FontUtils>. 
 
 
 =head1 LICENSING
 
-Copyright (c) 1998-2013, SIL International (http://www.sil.org) 
+Copyright (c) 1998-2014, SIL International (http://www.sil.org) 
 
 This module is released under the terms of the Artistic License 2.0. 
 For details, see the full text of the license in the file LICENSE.
