@@ -88,20 +88,21 @@ sub new
     bless $self, $class;
 }
 
+sub out_xml
+{
+}
+
 1;
 
 =head1 AUTHOR
 
-David Raymond L<David_Raymond@sil.org>. 
-
+David Raymond L<http://scripts.sil.org/FontUtils>. 
 
 =head1 LICENSING
 
-Copyright (c) 1998-2013, SIL International (http://www.sil.org) 
+Copyright (c) 1998-2014, SIL International (http://www.sil.org) 
 
 This module is released under the terms of the Artistic License 2.0. 
 For details, see the full text of the license in the file LICENSE.
 
-The test suite contains test fonts released under the SIL Open Font License 1.1, see OFL.txt.
-
 =cut
