@@ -8,12 +8,6 @@ Font::TTF::Woff::PrivateData - WOFF Private data
 
 Currently a stub, thus read() results in read_dat()
 
-=head1 INSTANCE VARIABLES
-
-=over 4
-
-=back
-
 =cut
 
 use Font::TTF::Utils;
@@ -23,20 +17,16 @@ require Font::TTF::Table;
 
 1;
 
-
 =head1 AUTHOR
 
-Bob Hallissy. L<Bob_Hallissy@sil.org>
-
+Bob Hallissy. L<http://scripts.sil.org/FontUtils>.
 
 =head1 LICENSING
 
-Copyright (c) 1998-2013, SIL International (http://www.sil.org) 
+Copyright (c) 1998-2014, SIL International (http://www.sil.org) 
 
 This module is released under the terms of the Artistic License 2.0. 
 For details, see the full text of the license in the file LICENSE.
 
-The test suite contains test fonts released under the SIL Open Font License 1.1, see OFL.txt.
-
 =cut
 
